@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.14;
 use warnings;
 
 use IO::Async::Loop;
@@ -29,4 +29,4 @@ my $filestream = IO::Async::FileStream->new(
 );
 $loop->add( $filestream );
 
-$loop->loop_forever;
+$loop->run;
