@@ -1,15 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2015-2024 -- leonerd@leonerd.org.uk
 
-package IO::Async::Debug;
+package IO::Async::Debug 0.803;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.802';
-
 our $DEBUG = $ENV{IO_ASYNC_DEBUG} || 0;
 our $DEBUG_FD   = $ENV{IO_ASYNC_DEBUG_FD};
 our $DEBUG_FILE = $ENV{IO_ASYNC_DEBUG_FILE};
