@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2012-2013 -- leonerd@leonerd.org.uk
 
-package IO::Async::OS::MSWin32;
+package IO::Async::OS::MSWin32 0.803;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.801';
-
 our @ISA = qw( IO::Async::OS::_Base );
 
 use Carp;
