@@ -1,16 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2018 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2024 -- leonerd@leonerd.org.uk
 
-package IO::Async::Process;
+package IO::Async::Process 0.803;
 
-use strict;
+use v5.14;
 use warnings;
 use base qw( IO::Async::Notifier );
 
-our $VERSION = '0.79';
-
 use Carp;
 
 use Socket qw( SOCK_STREAM );
@@ -139,7 +137,7 @@ used to distinguish the two cases:
 
 =head2 new
 
-   $process = IO::Async::Process->new( %args )
+   $process = IO::Async::Process->new( %args );
 
 Constructs a new C<IO::Async::Process> object and returns it.
 
@@ -265,7 +263,7 @@ use C<setsockopt(3)>) from the controlling parent, before the child code runs.
 The arguments passed in are the L<IO::Socket> objects for the parent and child
 ends of the socket.
 
-   $prefork->( $localfd, $childfd )
+   $prefork->( $localfd, $childfd );
 
 =back
 
@@ -601,7 +599,7 @@ sub notifier_name
 
 =head2 finish_future
 
-   $f = $process->finish_future
+   $f = $process->finish_future;
 
 I<Since version 0.75.>
 
@@ -618,7 +616,7 @@ sub finish_future
 
 =head2 pid
 
-   $pid = $process->pid
+   $pid = $process->pid;
 
 Returns the process ID of the process, if it has been started, or C<undef> if
 not. Its value is preserved after the process exits, so it may be inspected
@@ -634,7 +632,7 @@ sub pid
 
 =head2 kill
 
-   $process->kill( $signal )
+   $process->kill( $signal );
 
 Sends a signal to the process
 
@@ -650,7 +648,7 @@ sub kill
 
 =head2 is_running
 
-   $running = $process->is_running
+   $running = $process->is_running;
 
 Returns true if the Process has been started, and has not yet finished.
 
@@ -664,7 +662,7 @@ sub is_running
 
 =head2 is_exited
 
-   $exited = $process->is_exited
+   $exited = $process->is_exited;
 
 Returns true if the Process has finished running, and finished due to normal
 C<exit(2)>.
@@ -679,7 +677,7 @@ sub is_exited
 
 =head2 exitstatus
 
-   $status = $process->exitstatus
+   $status = $process->exitstatus;
 
 If the process exited due to normal C<exit(2)>, returns the value that was
 passed to C<exit(2)>. Otherwise, returns C<undef>.
@@ -694,7 +692,7 @@ sub exitstatus
 
 =head2 exception
 
-   $exception = $process->exception
+   $exception = $process->exception;
 
 If the process exited due to an exception, returns the exception that was
 thrown. Otherwise, returns C<undef>.
@@ -709,7 +707,7 @@ sub exception
 
 =head2 errno
 
-   $errno = $process->errno
+   $errno = $process->errno;
 
 If the process exited due to an exception, returns the numerical value of
 C<$!> at the time the exception was thrown. Otherwise, returns C<undef>.
@@ -724,7 +722,7 @@ sub errno
 
 =head2 errstr
 
-   $errstr = $process->errstr
+   $errstr = $process->errstr;
 
 If the process exited due to an exception, returns the string value of
 C<$!> at the time the exception was thrown. Otherwise, returns C<undef>.
@@ -739,7 +737,7 @@ sub errstr
 
 =head2 fd
 
-   $stream = $process->fd( $fd )
+   $stream = $process->fd( $fd );
 
 Returns the L<IO::Async::Stream> or L<IO::Async::Socket> associated with the
 given FD number. This must have been set up by a C<configure> argument prior
@@ -804,13 +802,13 @@ sub fd
 
 =head2 stdio
 
-   $stream = $process->stdin
+   $stream = $process->stdin;
 
-   $stream = $process->stdout
+   $stream = $process->stdout;
 
-   $stream = $process->stderr
+   $stream = $process->stderr;
 
-   $stream = $process->stdio
+   $stream = $process->stdio;
 
 Shortcuts for calling C<fd> with 0, 1, 2 or C<io> respectively, to obtain the
 L<IO::Async::Stream> representing the standard input, output, error, or
