@@ -1,16 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2024 -- leonerd@leonerd.org.uk
 
-package IO::Async::Timer::Periodic;
+package IO::Async::Timer::Periodic 0.803;
 
-use strict;
+use v5.14;
 use warnings;
 use base qw( IO::Async::Timer );
 
-our $VERSION = '0.800';
-
 use Carp;
 
 =head1 NAME
